Ricecooker utils
================
The ``ricecooker.utils`` module includes a number of utilities and helper functions
to help chef authors with common extraction and content transformation tasks.

.. toctree::
   :maxdepth: 1

   downloader
   parsing_html
   video_compression
   pdfutils
   csv_metadata/README
   csv_metadata/csv_exercises
